@@ -111,32 +111,32 @@ class Orden(BaseModel):
 
     def build_xml(self):
         mensaje = etree.Element('mensaje', categoria=self.categoria)
-        orden_pago = etree.SubElement(mensaje, 'ordenpago')
+        ordenpago = etree.SubElement(mensaje, 'ordenpago', Id=str(self.id))
 
         elements = self.dict(
             exclude_none=True,
-            exclude={'categoria', 'op_ord_clave'},
+            exclude={'id', 'categoria', 'op_ord_clave'},
         )
 
         for element, value in elements.items():  # noqa: WPS110
             if element in self.__fields__:
                 if element == 'op_firma_dig':
-                    subelement = etree.SubElement(orden_pago, 'opFirmaDig')
+                    subelement = etree.SubElement(ordenpago, 'opFirmaDig')
                     subelement.text = str(value)
                     continue
                 upper_camel_case_element = to_upper_camel_case(element)
-                subelement = etree.SubElement(orden_pago, upper_camel_case_element)
+                subelement = etree.SubElement(ordenpago, upper_camel_case_element)
                 subelement.text = str(value)
 
         return mensaje
 
     @classmethod
-    def parse_xml(cls, mensaje):
-        ordenpago = mensaje.find('ordenpago')
+    def parse_xml(cls, mensaje_element):
+        ordenpago = mensaje_element.find('ordenpago')
 
         orden_data = {
             'id': ordenpago.attrib['Id'],
-            'categoria': mensaje.attrib['categoria'],
+            'categoria': mensaje_element.attrib['categoria'],
         }
 
         for element in ordenpago.getchildren():
